@@ -25,15 +25,15 @@ with_mock_dir("hazard-batch",{
 # })
 
 test_that('DTXSID errors', {
-  expect_error(get_hazard_by_dtxsid_batch(DTXSID = 1, API_key = 'test_key'), 'Please input a character list for DTXSID!')
-  expect_error(get_hazard_by_dtxsid_batch(DTXSID = list('first' = '1', 'second' = 2), API_key = 'test_key'), 'Please input a character list for DTXSID!')
-  expect_error(get_hazard_by_dtxsid_batch(API_key = 'test_key'), 'Please input a list of DTXSIDs!')
-  expect_error(get_human_hazard_by_dtxsid_batch(DTXSID = 1, API_key = 'test_key'), 'Please input a character list for DTXSID!')
-  expect_error(get_human_hazard_by_dtxsid_batch(DTXSID = list('first' = '1', 'second' = 2), API_key = 'test_key'), 'Please input a character list for DTXSID!')
-  expect_error(get_human_hazard_by_dtxsid_batch(API_key = 'test_key'), 'Please input a list of DTXSIDs!')
-  expect_error(get_ecotox_hazard_by_dtxsid_batch(DTXSID = 1, API_key = 'test_key'), 'Please input a character list for DTXSID!')
-  expect_error(get_ecotox_hazard_by_dtxsid_batch(DTXSID = list('first' = '1', 'second' = 2), API_key = 'test_key'), 'Please input a character list for DTXSID!')
-  expect_error(get_ecotox_hazard_by_dtxsid_batch(API_key = 'test_key'), 'Please input a list of DTXSIDs!')
+  # expect_error(get_hazard_by_dtxsid_batch(DTXSID = 1, API_key = 'test_key'), 'Please input a character list for DTXSID!')
+  # expect_error(get_hazard_by_dtxsid_batch(DTXSID = list('first' = '1', 'second' = 2), API_key = 'test_key'), 'Please input a character list for DTXSID!')
+  # expect_error(get_hazard_by_dtxsid_batch(API_key = 'test_key'), 'Please input a list of DTXSIDs!')
+  # expect_error(get_human_hazard_by_dtxsid_batch(DTXSID = 1, API_key = 'test_key'), 'Please input a character list for DTXSID!')
+  # expect_error(get_human_hazard_by_dtxsid_batch(DTXSID = list('first' = '1', 'second' = 2), API_key = 'test_key'), 'Please input a character list for DTXSID!')
+  # expect_error(get_human_hazard_by_dtxsid_batch(API_key = 'test_key'), 'Please input a list of DTXSIDs!')
+  # expect_error(get_ecotox_hazard_by_dtxsid_batch(DTXSID = 1, API_key = 'test_key'), 'Please input a character list for DTXSID!')
+  # expect_error(get_ecotox_hazard_by_dtxsid_batch(DTXSID = list('first' = '1', 'second' = 2), API_key = 'test_key'), 'Please input a character list for DTXSID!')
+  # expect_error(get_ecotox_hazard_by_dtxsid_batch(API_key = 'test_key'), 'Please input a list of DTXSIDs!')
   expect_error(get_skin_eye_hazard_batch(DTXSID = 1, API_key = 'test_key'), 'Please input a character list for DTXSID!')
   expect_error(get_skin_eye_hazard_batch(DTXSID = list('first' = '1', 'second' = 2), API_key = 'test_key'), 'Please input a character list for DTXSID!')
   expect_error(get_skin_eye_hazard_batch(API_key = 'test_key'), 'Please input a list of DTXSIDs!')
@@ -51,10 +51,10 @@ test_that('DTXSID errors', {
 test_that('Rate limit warnings', {
   expect_warning(get_hazard_by_dtxsid_batch(DTXSID = c('DTXSID7020182'), API_key = ctx_key(), rate_limit = '0'), 'Setting rate limit to 0 seconds between requests!')
   expect_warning(get_hazard_by_dtxsid_batch(DTXSID = c('DTXSID7020182'), API_key = ctx_key(), rate_limit = -1), 'Setting rate limit to 0 seconds between requests!')
-  expect_warning(get_human_hazard_by_dtxsid_batch(DTXSID = c('DTXSID7020182'), API_key = ctx_key(), rate_limit = '0'), 'Setting rate limit to 0 seconds between requests!')
-  expect_warning(get_human_hazard_by_dtxsid_batch(DTXSID = c('DTXSID7020182'), API_key = ctx_key(), rate_limit = -1), 'Setting rate limit to 0 seconds between requests!')
-  expect_warning(get_ecotox_hazard_by_dtxsid_batch(DTXSID = c('DTXSID7020182'), API_key = ctx_key(), rate_limit = '0'), 'Setting rate limit to 0 seconds between requests!')
-  expect_warning(get_ecotox_hazard_by_dtxsid_batch(DTXSID = c('DTXSID7020182'), API_key = ctx_key(), rate_limit = -1), 'Setting rate limit to 0 seconds between requests!')
+  # expect_warning(get_human_hazard_by_dtxsid_batch(DTXSID = c('DTXSID7020182'), API_key = ctx_key(), rate_limit = '0'), 'Setting rate limit to 0 seconds between requests!')
+  # expect_warning(get_human_hazard_by_dtxsid_batch(DTXSID = c('DTXSID7020182'), API_key = ctx_key(), rate_limit = -1), 'Setting rate limit to 0 seconds between requests!')
+  # expect_warning(get_ecotox_hazard_by_dtxsid_batch(DTXSID = c('DTXSID7020182'), API_key = ctx_key(), rate_limit = '0'), 'Setting rate limit to 0 seconds between requests!')
+  # expect_warning(get_ecotox_hazard_by_dtxsid_batch(DTXSID = c('DTXSID7020182'), API_key = ctx_key(), rate_limit = -1), 'Setting rate limit to 0 seconds between requests!')
   expect_warning(get_skin_eye_hazard_batch(DTXSID = c('DTXSID7020182'), API_key = ctx_key(), rate_limit = '0'), 'Setting rate limit to 0 seconds between requests!')
   expect_warning(get_skin_eye_hazard_batch(DTXSID = c('DTXSID7020182'), API_key = ctx_key(), rate_limit = -1), 'Setting rate limit to 0 seconds between requests!')
   expect_warning(get_cancer_hazard_batch(DTXSID = c('DTXSID7020182'), API_key = ctx_key(), rate_limit = '0'), 'Setting rate limit to 0 seconds between requests!')
@@ -68,13 +68,13 @@ test_that('Rate limit warnings', {
 test_that('Return data types', {
   expect_type(get_hazard_by_dtxsid_batch(DTXSID = c('DTXSID7020182'), API_key = ctx_key()), 'list')
   expect_type(get_hazard_by_dtxsid_batch(DTXSID = c(''), API_key = ctx_key()), 'list')
-  #expect_type(get_hazard_by_dtxsid_batch(DTXSID = c('DTXSID7020182'), API_key = ''), 'list')
-  expect_type(get_human_hazard_by_dtxsid_batch(DTXSID = c('DTXSID7020182'), API_key = ctx_key()), 'list')
-  expect_type(get_human_hazard_by_dtxsid_batch(DTXSID = c(''), API_key = ctx_key()), 'list')
-  #expect_type(get_human_hazard_by_dtxsid_batch(DTXSID = c('DTXSID7020182'), API_key = ''), 'list')
-  expect_type(get_ecotox_hazard_by_dtxsid_batch(DTXSID = c('DTXSID7020182'), API_key = ctx_key()), 'list')
-  expect_type(get_ecotox_hazard_by_dtxsid_batch(DTXSID = c(''), API_key = ctx_key()), 'list')
-  #expect_type(get_ecotox_hazard_by_dtxsid_batch(DTXSID = c('DTXSID7020182'), API_key = ''), 'list')
+  expect_type(get_hazard_by_dtxsid_batch(DTXSID = c('DTXSID7020182'), API_key = ''), 'list')
+  # expect_type(get_human_hazard_by_dtxsid_batch(DTXSID = c('DTXSID7020182'), API_key = ctx_key()), 'list')
+  # expect_type(get_human_hazard_by_dtxsid_batch(DTXSID = c(''), API_key = ctx_key()), 'list')
+  # #expect_type(get_human_hazard_by_dtxsid_batch(DTXSID = c('DTXSID7020182'), API_key = ''), 'list')
+  # expect_type(get_ecotox_hazard_by_dtxsid_batch(DTXSID = c('DTXSID7020182'), API_key = ctx_key()), 'list')
+  # expect_type(get_ecotox_hazard_by_dtxsid_batch(DTXSID = c(''), API_key = ctx_key()), 'list')
+  # #expect_type(get_ecotox_hazard_by_dtxsid_batch(DTXSID = c('DTXSID7020182'), API_key = ''), 'list')
   expect_type(get_skin_eye_hazard_batch(DTXSID = c('DTXSID7020182'), API_key = ctx_key()), 'list')
   expect_type(get_skin_eye_hazard_batch(DTXSID = c(''), API_key = ctx_key()), 'list')
   #expect_type(get_skin_eye_hazard_batch(DTXSID = c('DTXSID7020182'), API_key = ''), 'list')
